% Figure3_1.m
% It requires the following functions:
% phiAh
% phiBh
% phiCh
% phiSSnABC
% phiSSnABCproc
% fABC.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global A B C
%A=10/2; B=10; C=30/2;
A=1; B=2; C=3;
%%%%%%%%%%%%%  ABC-flow   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial and final time
t0=0;  tf=20; 
% Initial Conditions 
x0 = [1 ; 2; 3];  x=[];
% Computing the numerical "exact" solution
  options = odeset('AbsTol',1e-15,'RelTol',1e-13);
  [t,x] = ode45('fABC',[t0,tf],x0,options);
  
for imet=1:5
erEnS=[]; erPosS=[]; costS=[];
   t=[]; xs=[];
    if imet==1
%  Coefficients of the processed SS_{13}^{6] method of 
%  Blanes-Casas-Murua, SISC(2006)
 nstages=13;
a1= 0.125696288720106; a5= 0.148070660114965; a6=-0.350856370823828;
al=[a1, a1,a1, a1,a5,a6, 1-2*(4*a1+a5+a6), a6, a5, a1, a1, a1, a1];
 np=12;
ga1= 0.1; ga2= 0.225080298761176; ga3= 0.191244694511161;
ga4=-0.212763792194890; ga5=-0.09660157306582295 ;
ga6=-(ga1+ga2+ga3+ga4+ga5);
ga7=-ga1; ga8=-ga2; ga9=-ga3; ga10=-ga4; ga11=-ga5; ga12=-ga6;
ga=-[ga1,ga2,ga3,ga4,ga5,ga6,ga7,ga8,ga9,ga10,ga11,ga12];

    elseif imet==2
nstages=3;
a1=1/(2-2^(1/3));
al=[a1, 1-2*a1, a1];

    elseif imet==3
%  Coefficients of the SS_5^[4] method of Suzuki
 nstages=5;
a1=1/(4-4^(1/3));
al=[a1, a1, 1-4*a1, a1, a1];

    elseif imet==4
%  Coefficients of the SS_9^[6] method of McLachlan
nstages=9;
a1=0.1867;
a2=0.55549702371247839916; a3=0.12946694891347535806; 
a4=-0.84326562338773460855;
al=[a1, a2,a3, a4, 1-2*(a1+a2+a3+a4), a4, a3, a2, a1];

    elseif imet==5
%  Coefficients of the SS_{17}^[8] method of McLachlan
nstages=17;
a1=25/194;
a2=0.58151408710525096243;
a3=-0.41017537146985013753;
a4=0.18514693571658773265;
a5=-0.40955234342085141934;
a6=0.14440594108001204106;
a7=0.27833550039367965131;
a8=0.31495668391629485789;
al=[a1,a2,a3,a4,a5,a6,a7,a8,1-2*(a1+a2+a3+a4+a5+a6+a7+a8), ...
    a8,a7,a6,a5,a4,a3,a2,a1];
    end
  
for i=1:9
   t=[]; xk1=[];    xk2=[];    xk4=[]; 
   N=3*2^i;  h = (tf-t0)/N;
if imet==1
   [t xs]=phiSSnABCproc(t0,tf,x0,N,al,nstages,ga,np);
else
   [t xs]=phiSSnABC(t0,tf,x0,N,al,nstages);
end

   erEnS=[erEnS; norm(x(end,:)-xs(end,:))]; costS=[costS; nstages*N];
end

figure(2)
  hold on
  if imet==1
       plot(log10(costS),log10(erEnS(:)),'--k','LineWidth',2)
       text(2.9,-5.5,'PS_{13}^{[6]}','FontSize',14)
 elseif imet==2
        plot(log10(costS),log10(erEnS(:)),':k','LineWidth',2)
       text(3.4,-3.8,'SS_{3}^{[4]}','FontSize',14)
  elseif imet==3
        plot(log10(costS),log10(erEnS(:)),'-sk','LineWidth',2)
       text(2.4,-2.8,'SS_{5}^{[4]}','FontSize',14)
  elseif imet==4
        plot(log10(costS),log10(erEnS(:)),'-dk','LineWidth',2)
       text(3.6,-7,'SS_{9}^{[6]}','FontSize',14)
  elseif imet==5
        plot(log10(costS),log10(erEnS(:)),'-pk','LineWidth',2)
       text(3.4,-9.5,'SS_{17}^{[8]}','FontSize',14)
  end
  axis([2.3 3.8 -10 0.5]) 
%  axis([1.5 3 -10 0.5]) 
  xlabel('{\fontsize{14} log_{10}(N. eval.) }')   
  ylabel('{\fontsize{14} log_{10}(Error)}')   
  title('{\fontsize{14} ABC-flow}')   
  box
end

